==> ukui-settings-daemon-debug-3.1.1.1-3-x86_64.pkg.tar.zst: usr/src/debug/ukui-settings-daemon/ukui-settings-daemon-3.1.1.1/plugins/housekeeping/qrc_trash_empty.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.8
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/ukui-settings-daemon/src/ukui-settings-daemon-3.1.1.1/plugins/housekeeping/warning.png
  0x0,0x0,0x0,0xe0,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x2,0x3,0x0,0x0,0x0,0xe,0x14,0x92,0x67,
  0x0,0x0,0x0,0xc,0x50,0x4c,0x54,0x45,0x65,0x2d,0x67,0x0,0x0,0x0,0x99,0x99,
  0x99,0xff,0xff,0x0,0xf0,0xa0,0x94,0xc,0x0,0x0,0x0,0x1,0x74,0x52,0x4e,0x53,
  0x0,0x40,0xe6,0xd8,0x66,0x0,0x0,0x0,0x82,0x49,0x44,0x41,0x54,0x18,0xd3,0x55,
  0xce,0xc1,0xd,0xc2,0x30,0xc,0x5,0x50,0xe7,0x80,0x32,0x1,0xe7,0xdc,0x99,0x82,
  0x25,0xda,0x19,0x10,0x4b,0x98,0x51,0x7a,0x44,0xd9,0x27,0x12,0xca,0x1e,0x85,0x53,
  0xf5,0xb1,0xbf,0x69,0x51,0xfe,0xc5,0x4f,0xb2,0xbe,0x65,0x11,0x91,0xb3,0xfc,0xa2,
  0xd7,0x98,0x9,0xaf,0x1d,0x3d,0x90,0xf1,0x7e,0x8c,0x28,0xd8,0x96,0x11,0xa,0xdc,
  0x2,0x2d,0x90,0x30,0x69,0x1f,0x90,0xd,0xec,0x1f,0x28,0x6,0xf6,0xf,0x28,0x5a,
  0x1c,0xda,0x91,0xe0,0xe8,0xc4,0x87,0xc8,0x84,0xf5,0xd,0x20,0xa,0xb0,0xc2,0x1f,
  0x31,0x34,0x75,0x28,0x61,0x7d,0xe5,0x2a,0xe0,0xb9,0xff,0x51,0x38,0xb7,0x2a,0xa7,
  0xc9,0x33,0x57,0x91,0xca,0x3c,0x45,0x2e,0xc4,0xf2,0x5,0x8d,0xd0,0x83,0x40,0x22,
  0x13,0x94,0x4e,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // new
  0x0,0x3,
  0x0,0x0,0x74,0xc7,
  0x0,0x6e,
  0x0,0x65,0x0,0x77,
    // prefix1
  0x0,0x7,
  0x7,0x8b,0xd0,0x51,
  0x0,0x70,
  0x0,0x72,0x0,0x65,0x0,0x66,0x0,0x69,0x0,0x78,0x0,0x31,
    // warning.png
  0x0,0xb,
  0x0,0xb5,0x45,0xe7,
  0x0,0x77,
  0x0,0x61,0x0,0x72,0x0,0x6e,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x86,0x50,0xe0,0xdf,0x80,
  // :/new
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x86,0x50,0xe0,0xdf,0x80,
  // :/new/prefix1
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x86,0x50,0xe0,0xdf,0x80,
  // :/new/prefix1/warning.png
  0x0,0x0,0x0,0x20,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x86,0x50,0xe0,0xdf,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_trash_empty)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_trash_empty)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_trash_empty)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_trash_empty)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_trash_empty)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_trash_empty)(); }
   } dummy;
}

==> ukui-settings-daemon-debug-3.1.1.1-4-x86_64.pkg.tar.zst: usr/src/debug/ukui-settings-daemon/ukui-settings-daemon-3.1.1.1/plugins/housekeeping/qrc_trash_empty.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.10
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/ukui-settings-daemon/src/ukui-settings-daemon-3.1.1.1/plugins/housekeeping/warning.png
  0x0,0x0,0x0,0xe0,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x2,0x3,0x0,0x0,0x0,0xe,0x14,0x92,0x67,
  0x0,0x0,0x0,0xc,0x50,0x4c,0x54,0x45,0x65,0x2d,0x67,0x0,0x0,0x0,0x99,0x99,
  0x99,0xff,0xff,0x0,0xf0,0xa0,0x94,0xc,0x0,0x0,0x0,0x1,0x74,0x52,0x4e,0x53,
  0x0,0x40,0xe6,0xd8,0x66,0x0,0x0,0x0,0x82,0x49,0x44,0x41,0x54,0x18,0xd3,0x55,
  0xce,0xc1,0xd,0xc2,0x30,0xc,0x5,0x50,0xe7,0x80,0x32,0x1,0xe7,0xdc,0x99,0x82,
  0x25,0xda,0x19,0x10,0x4b,0x98,0x51,0x7a,0x44,0xd9,0x27,0x12,0xca,0x1e,0x85,0x53,
  0xf5,0xb1,0xbf,0x69,0x51,0xfe,0xc5,0x4f,0xb2,0xbe,0x65,0x11,0x91,0xb3,0xfc,0xa2,
  0xd7,0x98,0x9,0xaf,0x1d,0x3d,0x90,0xf1,0x7e,0x8c,0x28,0xd8,0x96,0x11,0xa,0xdc,
  0x2,0x2d,0x90,0x30,0x69,0x1f,0x90,0xd,0xec,0x1f,0x28,0x6,0xf6,0xf,0x28,0x5a,
  0x1c,0xda,0x91,0xe0,0xe8,0xc4,0x87,0xc8,0x84,0xf5,0xd,0x20,0xa,0xb0,0xc2,0x1f,
  0x31,0x34,0x75,0x28,0x61,0x7d,0xe5,0x2a,0xe0,0xb9,0xff,0x51,0x38,0xb7,0x2a,0xa7,
  0xc9,0x33,0x57,0x91,0xca,0x3c,0x45,0x2e,0xc4,0xf2,0x5,0x8d,0xd0,0x83,0x40,0x22,
  0x13,0x94,0x4e,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // new
  0x0,0x3,
  0x0,0x0,0x74,0xc7,
  0x0,0x6e,
  0x0,0x65,0x0,0x77,
    // prefix1
  0x0,0x7,
  0x7,0x8b,0xd0,0x51,
  0x0,0x70,
  0x0,0x72,0x0,0x65,0x0,0x66,0x0,0x69,0x0,0x78,0x0,0x31,
    // warning.png
  0x0,0xb,
  0x0,0xb5,0x45,0xe7,
  0x0,0x77,
  0x0,0x61,0x0,0x72,0x0,0x6e,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x8a,0xea,0x10,0xeb,0x60,
  // :/new
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x8a,0xea,0x10,0xeb,0x60,
  // :/new/prefix1
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x8a,0xea,0x10,0xeb,0x60,
  // :/new/prefix1/warning.png
  0x0,0x0,0x0,0x20,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x8a,0xea,0x10,0xeb,0x60,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_trash_empty)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_trash_empty)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_trash_empty)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_trash_empty)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_trash_empty)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_trash_empty)(); }
   } dummy;
}
